/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 2

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Substitute the type names.  */
#define YYSTYPE         SHELL_STYPE
/* Substitute the variable and function names.  */
#define yyparse         shell_parse
#define yylex           shell_lex
#define yyerror         shell_error
#define yydebug         shell_debug
#define yynerrs         shell_nerrs


/* Copy the first part of user declarations.  */
#line 54 "parser/shellQuery.y" /* yacc.c:339  */
  
#include "mediatex-config.h"
#include "client/mediatex-client.h"
  /* yyscan_t is pre-defined by mediatex-config.h and will be defined
     by Flex header bellow */

#line 80 "parser/shellQuery.tab.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 1
#endif

/* In a future release of Bison, this section will be replaced
   by #include "shellQuery.tab.h".  */
#ifndef YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED
# define YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef SHELL_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define SHELL_DEBUG 1
#  else
#   define SHELL_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define SHELL_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined SHELL_DEBUG */
#if SHELL_DEBUG
extern int shell_debug;
#endif

/* Token type.  */
#ifndef SHELL_TOKENTYPE
# define SHELL_TOKENTYPE
  enum shell_tokentype
  {
    shellERROR = 258,
    shellEOL = 259,
    shellSTRING = 260,
    shellNUMBER = 261,
    shellCOLL = 262,
    shellSUPP = 263,
    shellKEY = 264,
    shellUSER = 265,
    shellADMIN = 266,
    shellSERVER = 267,
    shellMASTER = 268,
    shellALL = 269,
    shellTO = 270,
    shellFROM = 271,
    shellAS = 272,
    shellFOR = 273,
    shellON = 274,
    shellINIT = 275,
    shellREMOVE = 276,
    shellPURGE = 277,
    shellCLEAN = 278,
    shellADD = 279,
    shellDEL = 280,
    shellNOTE = 281,
    shellLIST = 282,
    shellUPDATE = 283,
    shellUPGRADE = 284,
    shellUPGRADEP = 285,
    shellCOMMIT = 286,
    shellMAKE = 287,
    shellCHECK = 288,
    shellBIND = 289,
    shellUNBIND = 290,
    shellMOUNT = 291,
    shellUMOUNT = 292,
    shellUPLOAD = 293,
    shellFILE = 294,
    shellCATALOG = 295,
    shellRULES = 296,
    shellUPLOADP = 297,
    shellUPLOADPP = 298,
    shellGET = 299,
    shellSU = 300,
    shellMOTD = 301,
    shellAUDIT = 302,
    shellDELIVER = 303,
    shellSAVE = 304,
    shellEXTRACT = 305,
    shellNOTIFY = 306,
    shellAROBASE = 307,
    shellCOLON = 308,
    shellMINUS = 309
  };
#endif
/* Tokens.  */
#define shellERROR 258
#define shellEOL 259
#define shellSTRING 260
#define shellNUMBER 261
#define shellCOLL 262
#define shellSUPP 263
#define shellKEY 264
#define shellUSER 265
#define shellADMIN 266
#define shellSERVER 267
#define shellMASTER 268
#define shellALL 269
#define shellTO 270
#define shellFROM 271
#define shellAS 272
#define shellFOR 273
#define shellON 274
#define shellINIT 275
#define shellREMOVE 276
#define shellPURGE 277
#define shellCLEAN 278
#define shellADD 279
#define shellDEL 280
#define shellNOTE 281
#define shellLIST 282
#define shellUPDATE 283
#define shellUPGRADE 284
#define shellUPGRADEP 285
#define shellCOMMIT 286
#define shellMAKE 287
#define shellCHECK 288
#define shellBIND 289
#define shellUNBIND 290
#define shellMOUNT 291
#define shellUMOUNT 292
#define shellUPLOAD 293
#define shellFILE 294
#define shellCATALOG 295
#define shellRULES 296
#define shellUPLOADP 297
#define shellUPLOADPP 298
#define shellGET 299
#define shellSU 300
#define shellMOTD 301
#define shellAUDIT 302
#define shellDELIVER 303
#define shellSAVE 304
#define shellEXTRACT 305
#define shellNOTIFY 306
#define shellAROBASE 307
#define shellCOLON 308
#define shellMINUS 309

/* Value type.  */
#if ! defined SHELL_STYPE && ! defined SHELL_STYPE_IS_DECLARED
typedef union SHELL_STYPE SHELL_STYPE;
union SHELL_STYPE
{
#line 61 "parser/shellQuery.y" /* yacc.c:355  */

  int         number;
  char        string[MAX_SIZE_STRING+1];
  Collection* coll;

#line 242 "parser/shellQuery.tab.c" /* yacc.c:355  */
};
# define SHELL_STYPE_IS_TRIVIAL 1
# define SHELL_STYPE_IS_DECLARED 1
#endif



int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
/* "%code provides" blocks.  */
#line 26 "parser/shellQuery.y" /* yacc.c:355  */

/*=======================================================================
 * Version: this file is generated by BISON using shellQuery.y
 * Project: Mediatex
 * Module : shell parser
 *
 * shell query parser.

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 2016 Nicolas Roche
   
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
   
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
   
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE SHELL_STYPE

#line 280 "parser/shellQuery.tab.c" /* yacc.c:355  */

#endif /* !YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED  */

/* Copy the second part of user declarations.  */
#line 67 "parser/shellQuery.y" /* yacc.c:358  */

  // upper YYSTYPE union is required by Flex headers
#include "parser/shellQuery.h"

void shell_error(yyscan_t yyscanner, Collection* coll, 
		 UploadParams* upParam, const char* message);

#line 293 "parser/shellQuery.tab.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined SHELL_STYPE_IS_TRIVIAL && SHELL_STYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  76
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   202

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  55
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  22
/* YYNRULES -- Number of rules.  */
#define YYNRULES  80
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  192

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   309

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54
};

#if SHELL_DEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   158,   158,   163,   168,   173,   178,   184,   190,   191,
     194,   199,   204,   208,   210,   214,   216,   217,   219,   223,
     225,   233,   241,   252,   253,   258,   277,   282,   284,   297,
     317,   324,   331,   338,   345,   352,   364,   373,   382,   391,
     400,   409,   417,   425,   433,   441,   449,   457,   470,   478,
     486,   494,   505,   514,   523,   532,   541,   550,   559,   568,
     575,   584,   593,   603,   613,   626,   635,   644,   651,   658,
     665,   679,   688,   697,   706,   713,   720,   727,   734,   748,
     757
};
#endif

#if SHELL_DEBUG || YYERROR_VERBOSE || 1
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "shellERROR", "shellEOL", "shellSTRING",
  "shellNUMBER", "shellCOLL", "shellSUPP", "shellKEY", "shellUSER",
  "shellADMIN", "shellSERVER", "shellMASTER", "shellALL", "shellTO",
  "shellFROM", "shellAS", "shellFOR", "shellON", "shellINIT",
  "shellREMOVE", "shellPURGE", "shellCLEAN", "shellADD", "shellDEL",
  "shellNOTE", "shellLIST", "shellUPDATE", "shellUPGRADE", "shellUPGRADEP",
  "shellCOMMIT", "shellMAKE", "shellCHECK", "shellBIND", "shellUNBIND",
  "shellMOUNT", "shellUMOUNT", "shellUPLOAD", "shellFILE", "shellCATALOG",
  "shellRULES", "shellUPLOADP", "shellUPLOADPP", "shellGET", "shellSU",
  "shellMOTD", "shellAUDIT", "shellDELIVER", "shellSAVE", "shellEXTRACT",
  "shellNOTIFY", "shellAROBASE", "shellCOLON", "shellMINUS", "$accept",
  "collection", "support", "file", "key", "newCollection",
  "newCollection2", "newCollUser", "newCollConf", "newCollLabel",
  "newCollHost", "newCollPort", "uploadParams", "target", "uploadParam",
  "queries", "query", "apiQuery", "admConfQuery", "srvQuery",
  "apiSuppQuery", "apiCollQuery", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309
};
# endif

#define YYPACT_NINF -21

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-21)))

#define YYTABLE_NINF -11

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int16 yypact[] =
{
       0,   -21,    41,    42,     9,    -3,    32,     6,    73,    60,
      64,    80,     6,    72,    72,    72,    91,     4,    11,    49,
     -21,   -21,   -21,   -21,    66,    70,    75,    89,    94,   101,
     102,   103,    85,    90,   112,   115,   116,   -21,   118,   119,
     120,   121,   -21,   -21,   122,   124,   125,   126,   127,    20,
     129,   111,    -1,   113,   117,   131,   132,   130,   -21,   134,
     -21,   135,   -21,   136,   123,   138,   139,   128,    13,   -21,
      16,    19,   -21,   137,   -21,   133,   -21,   -21,   -21,   -21,
     -21,   141,   143,   144,   145,   148,   -21,   149,   -21,   150,
     -21,   151,   -21,   -21,   140,   152,   146,   -21,   -21,   -21,
     -21,   -21,   -21,   -21,   -21,   -21,     3,   153,   -21,    11,
     -21,    30,    11,   155,   -21,   -21,   157,   -21,   -21,   -21,
     159,   -21,   -21,   160,   -21,    11,   -21,    11,    11,   -21,
     161,   158,   -21,   114,    96,   142,   -21,   163,   -21,   -21,
     -21,   -21,   164,   -21,   165,   167,   168,   169,   170,   171,
     172,   173,   174,   -21,   175,   -21,   176,   177,   178,   179,
     -21,   180,   104,   181,   -21,   183,   182,   -21,   -21,   -21,
     -21,   -21,   -21,   -21,   -21,   -21,   -21,   -21,   -21,   -21,
     -21,   184,   -21,   -21,   -21,   -21,   186,   -21,   185,   187,
     189,   -21
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,    24,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      23,    27,    28,    29,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    25,     0,     0,
       0,     0,    26,    74,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    70,     0,
      78,     0,    72,     0,     0,     0,     0,    19,     0,    17,
       0,     0,    76,     0,    69,     0,     1,    30,    31,    32,
       7,     0,     0,     0,     0,     0,    37,     0,    39,     0,
      41,     0,    43,    44,     0,     0,     0,    51,    48,    49,
      50,     2,    75,     3,     5,     4,     0,     0,    57,     0,
      58,     0,     0,     0,    68,    59,     0,    71,    79,    73,
       0,    21,    22,     0,    20,     0,    16,     0,     0,    77,
       0,     0,    35,    11,    13,     0,     9,     0,    36,    38,
      40,    42,     0,    46,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    67,     0,    18,     0,     0,     0,     0,
      33,     0,    15,     0,    34,     0,     0,    52,    53,    56,
      65,    54,    55,    66,    60,    61,    62,    63,    64,    80,
      12,     0,     6,    11,     8,    45,     0,    14,     0,     0,
       0,    47
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
     -21,    -9,    76,   190,   188,   -21,   -21,   -21,   -21,    21,
     -21,   -21,   100,   -21,   -20,   -21,   -21,   -21,   -21,   -21,
     -21,   -21
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,    45,    49,    67,    51,    82,    83,   134,   135,   136,
     162,   182,    68,   124,    69,    19,    20,    21,    37,    42,
      22,    23
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      59,    61,    63,   110,     1,    46,    47,    73,    74,    75,
      44,     2,     3,    43,    46,   111,    44,   145,    44,    85,
      87,    89,    91,     4,     5,     6,     7,     8,   125,     9,
      10,   127,    11,    12,   128,   106,    48,    44,    13,   107,
      46,    47,    14,    15,   149,    16,    17,    18,   126,    76,
     126,   126,    48,    65,    66,    48,    65,    66,    48,    65,
      66,    24,    25,    26,    58,    27,    28,    44,    60,    29,
      77,    44,    30,    31,    78,    32,    33,    34,    35,    79,
      55,    56,    52,    54,    62,    36,    57,    44,    64,    92,
      38,    39,    40,    41,    93,    72,    80,   146,    44,    81,
     148,    44,   150,   151,    84,    86,    88,    90,    44,    44,
      44,    48,    65,    66,    70,    71,   156,    94,   157,   158,
      95,    96,    97,    98,    99,   100,   109,   101,   102,   112,
     103,   104,   105,   108,   113,   114,   115,   116,   117,   118,
     119,   129,   120,   121,   122,   123,   131,   132,   161,   133,
     137,   130,   138,   139,   140,   141,   143,   181,   147,   142,
     152,   153,   160,   144,   154,   155,   159,   164,   -10,   165,
     166,   167,   168,   169,   170,   171,   172,   173,   174,   175,
     176,   177,   178,   179,   184,   180,   183,   185,     0,     0,
     187,   188,   190,   191,    53,    50,   163,     0,     0,     0,
       0,   186,   189
};

static const yytype_int16 yycheck[] =
{
       9,    10,    11,     4,     4,     8,     9,    16,     4,    18,
       7,    11,    12,     4,     8,    16,     7,    14,     7,    28,
      29,    30,    31,    23,    24,    25,    26,    27,    15,    29,
      30,    15,    32,    33,    15,    15,    39,     7,    38,    19,
       8,     9,    42,    43,    14,    45,    46,    47,    68,     0,
      70,    71,    39,    40,    41,    39,    40,    41,    39,    40,
      41,    20,    21,    22,     4,    24,    25,     7,     4,    28,
       4,     7,    31,    32,     4,    34,    35,    36,    37,     4,
       7,     8,     6,     7,     4,    44,    13,     7,    12,     4,
      48,    49,    50,    51,     4,     4,     7,   106,     7,    10,
     109,     7,   111,   112,    10,     4,     4,     4,     7,     7,
       7,    39,    40,    41,    14,    15,   125,     5,   127,   128,
       5,     5,     4,     4,     4,     4,    15,     5,     4,    16,
       5,     5,     5,     4,    17,     4,     4,     7,     4,     4,
       4,     4,    19,     5,     5,    17,     5,     4,    52,     5,
       5,    18,     4,     4,     4,     4,     4,    53,     5,    19,
       5,     4,     4,    17,     5,     5,     5,     4,    54,     5,
       5,     4,     4,     4,     4,     4,     4,     4,     4,     4,
       4,     4,     4,     4,   163,     5,     5,     4,    -1,    -1,
       6,     5,     5,     4,     6,     5,    54,    -1,    -1,    -1,
      -1,    19,    17
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,     4,    11,    12,    23,    24,    25,    26,    27,    29,
      30,    32,    33,    38,    42,    43,    45,    46,    47,    70,
      71,    72,    75,    76,    20,    21,    22,    24,    25,    28,
      31,    32,    34,    35,    36,    37,    44,    73,    48,    49,
      50,    51,    74,     4,     7,    56,     8,     9,    39,    57,
      58,    59,    57,    59,    57,     7,     8,    13,     4,    56,
       4,    56,     4,    56,    57,    40,    41,    58,    67,    69,
      67,    67,     4,    56,     4,    56,     0,     4,     4,     4,
       7,    10,    60,    61,    10,    56,     4,    56,     4,    56,
       4,    56,     4,     4,     5,     5,     5,     4,     4,     4,
       4,     5,     4,     5,     5,     5,    15,    19,     4,    15,
       4,    16,    16,    17,     4,     4,     7,     4,     4,     4,
      19,     5,     5,    17,    68,    15,    69,    15,    15,     4,
      18,     5,     4,     5,    62,    63,    64,     5,     4,     4,
       4,     4,    19,     4,    17,    14,    56,     5,    56,    14,
      56,    56,     5,     4,     5,     5,    56,    56,    56,     5,
       4,    52,    65,    54,     4,     5,     5,     4,     4,     4,
       4,     4,     4,     4,     4,     4,     4,     4,     4,     4,
       5,    53,    66,     5,    64,     4,    19,     6,     5,    17,
       5,     4
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    55,    56,    57,    58,    59,    60,    61,    62,    62,
      63,    64,    65,    65,    66,    66,    67,    67,    68,    68,
      69,    69,    69,    70,    70,    71,    71,    71,    72,    72,
      73,    73,    73,    73,    73,    73,    73,    73,    73,    73,
      73,    73,    73,    73,    73,    73,    73,    73,    74,    74,
      74,    74,    75,    75,    75,    75,    75,    75,    75,    75,
      75,    75,    75,    75,    75,    76,    76,    76,    76,    76,
      76,    76,    76,    76,    76,    76,    76,    76,    76,    76,
      76
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     2,     2,     2,     2,     4,     1,     3,     1,
       1,     1,     2,     0,     2,     0,     2,     1,     2,     0,
       2,     2,     2,     1,     1,     2,     2,     1,     1,     1,
       2,     2,     2,     4,     4,     3,     3,     2,     3,     2,
       3,     2,     3,     2,     2,     5,     3,     9,     2,     2,
       2,     2,     5,     5,     5,     5,     5,     3,     3,     3,
       5,     5,     5,     5,     5,     5,     5,     4,     3,     2,
       2,     3,     2,     3,     2,     3,     2,     3,     2,     3,
       5
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (yyscanner, coll, upParam, YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if SHELL_DEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value, yyscanner, coll, upParam); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, UploadParams* upParam)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  YYUSE (yyscanner);
  YYUSE (coll);
  YYUSE (upParam);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, UploadParams* upParam)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner, coll, upParam);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner, Collection* coll, UploadParams* upParam)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              , yyscanner, coll, upParam);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner, coll, upParam); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !SHELL_DEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !SHELL_DEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner, Collection* coll, UploadParams* upParam)
{
  YYUSE (yyvaluep);
  YYUSE (yyscanner);
  YYUSE (coll);
  YYUSE (upParam);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/*----------.
| yyparse.  |
`----------*/

int
yyparse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam)
{
/* The lookahead symbol.  */
int yychar;


/* The semantic value of the lookahead symbol.  */
/* Default value used for initialization, for pacifying older GCCs
   or non-GCC compilers.  */
YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);

    /* Number of syntax errors so far.  */
    int yynerrs;

    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex (&yylval, yyscanner);
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 159 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strcpy((yyval.string), (yyvsp[0].string));
}
#line 1519 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 3:
#line 164 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strcpy((yyval.string), (yyvsp[0].string));
}
#line 1527 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 4:
#line 169 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strcpy((yyval.string), (yyvsp[0].string));
}
#line 1535 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 5:
#line 174 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strcpy((yyval.string), (yyvsp[0].string));
}
#line 1543 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 6:
#line 179 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  (yyval.coll) = coll;
  coll = 0;
}
#line 1552 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 7:
#line 185 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  // addCollection will be call later
  if (!(coll = createCollection())) YYABORT;
}
#line 1561 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 10:
#line 195 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  if (!(coll->masterLabel = createString((yyvsp[0].string)))) YYABORT;
}
#line 1569 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 11:
#line 200 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strncpy(coll->label, (yyvsp[0].string), MAX_SIZE_COLL);
}
#line 1577 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 12:
#line 205 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  strncpy(coll->masterHost, (yyvsp[0].string), MAX_SIZE_HOST);
}
#line 1585 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 14:
#line 211 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  coll->masterPort = (yyvsp[0].number);
}
#line 1593 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 18:
#line 220 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  if (!(upParam->target = createString((yyvsp[0].string)))) YYABORT;
}
#line 1601 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 20:
#line 226 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  if (upParam->file) {
    logParser(LOG_ERR, "please only provide one data file to upload");
    YYABORT;
  }
  if (!(upParam->file = createString((yyvsp[-1].string)))) YYABORT;
}
#line 1613 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 21:
#line 234 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  if (upParam->catalog) {
    logParser(LOG_ERR, "please only provide catalog file to upload");
    YYABORT;
  }
  if (!(upParam->catalog = createString((yyvsp[0].string)))) YYABORT;
}
#line 1625 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 22:
#line 242 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  if (upParam->extract) {
    logParser(LOG_ERR, "please only provide one extract file to upload");
    YYABORT;
  }
  if (!(upParam->extract = createString((yyvsp[0].string)))) YYABORT;
}
#line 1637 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 24:
#line 254 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_ERR, "please use the -h flag to get help\n");
}
#line 1645 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 30:
#line 318 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "initializing mediatex software");
  if (!env.noRegression) {
    if (!mdtxInit()) YYABORT;
  }
}
#line 1656 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 31:
#line 325 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "removing mediatex software");
  if (!env.noRegression) {
    if (!mdtxRemove()) YYABORT;
  }
}
#line 1667 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 32:
#line 332 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "purging mediatex software");
  if (!env.noRegression) {
    if (!mdtxPurge()) YYABORT;
  }
}
#line 1678 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 33:
#line 339 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add %s user to groups", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!mdtxAddUser((yyvsp[-1].string))) YYABORT;
  }
}
#line 1689 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 34:
#line 346 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "del %s user from groups", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!mdtxDelUser((yyvsp[-1].string))) YYABORT;
  }
}
#line 1700 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 35:
#line 353 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  int rc = TRUE;
  logParser(LOG_INFO, "create/join new %s collection", (yyvsp[-1].coll)->label);
  if (!env.noRegression) {
    rc=rc&& clientWriteLock();
    rc=rc&& mdtxAddCollection((yyvsp[-1].coll));
    rc=rc&& clientWriteUnlock();
  }
  destroyCollection((yyvsp[-1].coll));
  if (!rc) YYABORT;
}
#line 1716 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 36:
#line 365 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "free the %s collection", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxDelCollection((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1729 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 37:
#line 374 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "update all");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!clientLoop(mdtxUpdate)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1742 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 38:
#line 383 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "update collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUpdate((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1755 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 39:
#line 392 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "commit all");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!clientLoop(mdtxCommit)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1768 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 40:
#line 401 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "commit collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxCommit((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1781 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 41:
#line 410 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "quickly make all");
  if (!env.noRegression) {
    env.noGitPullPush = TRUE; // disable git to reach network
    if (!clientLoop(mdtxMake)) YYABORT;
  }
}
#line 1793 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 42:
#line 418 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "quickly make collection");
  if (!env.noRegression) {
    env.noGitPullPush = TRUE; // disable git to reach network
    if (!mdtxMake((yyvsp[-1].string))) YYABORT;
  }
}
#line 1805 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 43:
#line 426 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "bind mediatex directories");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxBind()) YYABORT;
  }
}
#line 1817 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 44:
#line 434 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "unbind mediatex directories");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxUnbind()) YYABORT;
  }
}
#line 1829 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 45:
#line 442 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "mount %s on %s", (yyvsp[-3].string), (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxMount((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
  }
}
#line 1841 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 46:
#line 450 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "umount %s", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxUmount((yyvsp[-1].string))) YYABORT;
  }
}
#line 1853 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 47:
#line 459 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "get %s as %s on %s as %s", (yyvsp[-7].string), (yyvsp[-5].string), (yyvsp[-3].string), (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    env.noGit = TRUE; // do not use git at all (no commit)
    if (!mdtxScp((yyvsp[-5].string), (yyvsp[-3].string), (yyvsp[-7].string), (yyvsp[-1].string))) YYABORT;
  }
}
#line 1866 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 48:
#line 471 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "send SAVEMD5 signal to daemon");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxSyncSignal(MDTX_SAVEMD5)) YYABORT;
  }
}
#line 1878 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 49:
#line 479 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "send EXTRACT signal to daemon");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxSyncSignal(MDTX_EXTRACT)) YYABORT;
  }
}
#line 1890 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 50:
#line 487 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "send NOTIFY signal to daemon");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxSyncSignal(MDTX_NOTIFY)) YYABORT;
  }
}
#line 1902 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 51:
#line 495 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "send DELIVER signal to daemon");
  if (!env.noRegression) {
    if (!allowedUser(env.confLabel)) YYABORT;
    if (!mdtxSyncSignal(MDTX_DELIVER)) YYABORT;
  }
}
#line 1914 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 52:
#line 506 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add a support to all collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxShareSupport((yyvsp[-3].string), 0)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1927 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 53:
#line 515 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add a support to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxShareSupport((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1940 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 54:
#line 524 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "del a support from all collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxWithdrawSupport((yyvsp[-3].string), 0)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1953 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 55:
#line 533 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "del a support from a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxWithdrawSupport((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1966 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 56:
#line 542 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add %s support on %s", (yyvsp[-3].string), (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxAddSupport((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1979 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 57:
#line 551 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add %s file", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxAddFile((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 1992 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 58:
#line 560 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "remove a support");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxDelSupport((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2005 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 59:
#line 569 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "list local supports");
  if (!env.noRegression) {
    if (!mdtxLsSupport()) YYABORT;
  }
}
#line 2016 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 60:
#line 576 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "note a support as \"%s\"", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUpdateSupport((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2029 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 61:
#line 585 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "check content located at %s", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxHaveSupport((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2042 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 62:
#line 594 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upload a file to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUpload((yyvsp[-1].string), upParam->catalog, upParam->extract, 
		    upParam->file, upParam->target)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2056 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 63:
#line 604 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upload+ a file to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUploadPlus((yyvsp[-1].string), upParam->catalog, upParam->extract, 
		    upParam->file, upParam->target)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2070 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 64:
#line 614 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upload++ a file to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUploadPlusPlus((yyvsp[-1].string), upParam->catalog, upParam->extract, 
		    upParam->file, upParam->target)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2084 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 65:
#line 627 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "add a key to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!addKey((yyvsp[-1].string), (yyvsp[-3].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2097 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 66:
#line 636 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "del a key to a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!delKey((yyvsp[-1].string), (yyvsp[-3].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2110 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 67:
#line 645 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "listing locally hosted collections");
  if (!env.noRegression) {
    if (!mdtxListCollection(TRUE)) YYABORT;
  }
}
#line 2121 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 68:
#line 652 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "listing collections");
  if (!env.noRegression) {
    if (!mdtxListCollection(FALSE)) YYABORT;
  }
}
#line 2132 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 69:
#line 659 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "message of the day");
  if (!env.noRegression) {
    if (!updateMotd()) YYABORT;
  }
}
#line 2143 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 70:
#line 666 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upgrade all");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    
    // needed if there is still no collection
    if (!loadConfiguration(CFG)) YYABORT;
    getConfiguration()->fileState[iCFG] = MODIFIED; 
    
    if (!clientLoop(mdtxUpgrade)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2161 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 71:
#line 680 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upgrade a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUpgrade((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2174 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 72:
#line 689 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "make all");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!clientLoop(mdtxMake)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2187 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 73:
#line 698 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "build a HTML catalog");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxMake((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2200 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 74:
#line 707 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "clean all");
  if (!env.noRegression) {
    if (!clientLoop(mdtxClean)) YYABORT;
  }
}
#line 2211 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 75:
#line 714 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "clean an HTML catalog", (yyvsp[-1].string));
  if (!env.noRegression) {
    if (!mdtxClean((yyvsp[-1].string))) YYABORT;
  }
}
#line 2222 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 76:
#line 721 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "change to mediatex user");
  if (!env.noRegression) {
    if (!mdtxSu(0)) YYABORT;
  }
}
#line 2233 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 77:
#line 728 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "change to collection user");
  if (!env.noRegression) {
    if (!mdtxSu((yyvsp[-1].string))) YYABORT;
  }
}
#line 2244 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 78:
#line 735 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upgrade+ all");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    
    // needed if there is still no collection
    if (!loadConfiguration(CFG)) YYABORT;
    getConfiguration()->fileState[iCFG] = MODIFIED; 

    if (!clientLoop(mdtxUpgradePlus)) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2262 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 79:
#line 749 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "upgrade+ a collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxUpgradePlus((yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2275 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;

  case 80:
#line 758 "parser/shellQuery.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "audit collection");
  if (!env.noRegression) {
    if (!clientWriteLock()) YYABORT;
    if (!mdtxAudit((yyvsp[-3].string), (yyvsp[-1].string))) YYABORT;
    if (!clientWriteUnlock()) YYABORT;
  }
}
#line 2288 "parser/shellQuery.tab.c" /* yacc.c:1646  */
    break;


#line 2292 "parser/shellQuery.tab.c" /* yacc.c:1646  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (yyscanner, coll, upParam, YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yyscanner, coll, upParam, yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval, yyscanner, coll, upParam);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp, yyscanner, coll, upParam);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (yyscanner, coll, upParam, YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, yyscanner, coll, upParam);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp, yyscanner, coll, upParam);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 767 "parser/shellQuery.y" /* yacc.c:1906  */



/*=======================================================================
 * Function   : yyerror
 * Description: Emit an error message. Called by the parser on error
 *              state.
 * Synopsis   : void parsererror(char* message)
 * Input      : char* message = the error message.
 * Output     : N/A
 =======================================================================*/
void shell_error(yyscan_t yyscanner, Collection* coll, 
		 UploadParams* upParam, const char* message)
{
  logParser(LOG_ERR, "%s on token '%s'",
	  message, shell_get_text(yyscanner));
  logParser(LOG_NOTICE,
	    "bad invocation of mdtx's shell. Try auto-completion:");
  logParser(LOG_NOTICE,
	    "-> $ . /etc/bash_completion.d/mediatex_comp");
}


/*=======================================================================
 * Function   : parseShellQuery
 * Description: Parse the mediatex shell query
 * Synopsis   : int parseShellQuery(int argc, char** argv, int optind)
 * Input      : int argc, char** argv, int optind
 * Output     : TRUE on success
=======================================================================*/
int 
parseShellQuery(int argc, char** argv, int optind)
{
  int rc = FALSE;
  void* buffer = 0;
  yyscan_t scanner;
  Collection* coll = 0;
  UploadParams upParam = {0, 0, 0};

  logParser(LOG_DEBUG, "parseShellQuery");
  if (!getCommandLine(argc, argv, optind)) {
    rc = TRUE; // no query
    goto error;
  }
    
  // initialise parser
  if (shell_lex_init(&scanner)) {
    logParser(LOG_ERR, "shell_lex_init fails");
    goto error;
  }

  shell_set_debug(env.debugLexer, scanner);
  logParser(LOG_DEBUG, "shell_set_debug = %i", shell_get_debug(scanner));
  
  buffer = shell__scan_string(env.commandLine, scanner);
  
  // call parser 
  if (shell_parse(scanner, coll, &upParam)) {
    goto error2;
  }

  rc = TRUE;
 error2:
  shell__delete_buffer(buffer, scanner);
  shell_lex_destroy(scanner);  
 error:
  if (!rc) {
    logParser(LOG_ERR, "query fails");
  }
  destroyString(upParam.catalog);
  destroyString(upParam.extract);
  destroyString(upParam.file);
  destroyString(upParam.target);
  return rc;
}

/* Local Variables: */
/* mode: c */
/* mode: font-lock */
/* mode: auto-fill */
/* End: */

 
